Documentation
¶
Overview ¶
Package gormstore composes the workflow persistence interfaces over a caller-owned Gorm database. Database drivers and connection ownership remain the responsibility of the host application.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Options ¶
type Options struct {
Credentials credential.Store
Recovery RecoveryMode
// Close transfers connection ownership to the returned bundle when set.
// Leave nil when the host application owns the connection pool.
Close func() error
}
type RecoveryMode ¶
type RecoveryMode string
const ( // RecoveryDisabled is safe for shared databases because it does not mutate // runs that may be owned by another live process. RecoveryDisabled RecoveryMode = "disabled" // RecoveryFailInterrupted is only safe when this process is the exclusive // scheduler owner for the database. RecoveryFailInterrupted RecoveryMode = "fail_interrupted" )
Click to show internal directories.
Click to hide internal directories.